summaryrefslogtreecommitdiff
path: root/shared/fileHandling.h
diff options
context:
space:
mode:
authorDaniel Wilhelm <daniel@wili.li>2014-04-18 17:07:43 +0200
committerDaniel Wilhelm <daniel@wili.li>2014-04-18 17:07:43 +0200
commit4226e548662339ea1ca37b45385a7cf9b237ff1e (patch)
tree9a3fa54b85d97f05164e41bdb96b82f748a37342 /shared/fileHandling.h
parent3.7 (diff)
downloadFreeFileSync-4226e548662339ea1ca37b45385a7cf9b237ff1e.tar.gz
FreeFileSync-4226e548662339ea1ca37b45385a7cf9b237ff1e.tar.bz2
FreeFileSync-4226e548662339ea1ca37b45385a7cf9b237ff1e.zip
3.8
Diffstat (limited to 'shared/fileHandling.h')
-rw-r--r--shared/fileHandling.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/shared/fileHandling.h b/shared/fileHandling.h
index 7e1b3de0..6c57e8e4 100644
--- a/shared/fileHandling.h
+++ b/shared/fileHandling.h
@@ -35,8 +35,9 @@ enum ResponseSameVol
};
ResponseSameVol onSameVolume(const Zstring& folderLeft, const Zstring& folderRight); //throw()
-//optionally: copy creation/last change date, DOES NOTHING if something fails
-void copyFileTimes(const Zstring& sourceDir, const Zstring& targetDir); //throw()
+//optionally: copy file or directory create/last change date, DOES NOTHING if something fails
+//does NOT dereference symlinks!
+bool copyFileTimes(const Zstring& sourceDir, const Zstring& targetDir, bool deRefSymlinks); //throw(); returns true on success
//symlink handling: always evaluate target
wxULongLong getFilesize(const Zstring& filename); //throw (FileError)
@@ -70,7 +71,7 @@ void moveFile(const Zstring& sourceFile, const Zstring& targetFile, MoveFileCall
void moveDirectory(const Zstring& sourceDir, const Zstring& targetDir, bool ignoreExistingDirs, MoveFileCallback* callback = NULL); //throw (FileError);
//creates superdirectories automatically:
-void createDirectory(const Zstring& directory, const Zstring& templateDir = Zstring(), const bool copyDirectorySymLinks = false); //throw (FileError);
+void createDirectory(const Zstring& directory, const Zstring& templateDir = Zstring(), bool copyDirectorySymLinks = false); //throw (FileError);
struct CopyFileCallback //callback functionality
{
bgstack15